@@ -327,6 +327,7 @@ class Gps(QGraphicsEllipseItem):
         gradient.setColorAt(1, Qt.black)
         gradient.setColorAt(0, Qt.red)
         self.setPen(QPen(gradient, _RAYON))
+        self.state = False
         
     def width(self):
         return self.rect().width()
@@ -347,4 +348,51 @@ class Gps(QGraphicsEllipseItem):
         gradient.setColorAt(0, Qt.red)
         self.setPen(QPen(gradient, _RAYON))
 
+class diagLigne(QDialog):   
+    def __init__(self, already, parent=None):
+        super(diagLigne, self).__init__(parent)
 
+
+        self.setWindowTitle("Rtap : Lignes")
+        self.resize(800,400)
+        self.Layout = QGridLayout(self)
+        
+        self.List = QListWidget(self)
+        self.List.setSelectionMode(QAbstractItemView.MultiSelection)
+        
+#        for line in ['Metro 1','Metro 2', 'Metro 3', 'Metro 4', 'Metro 5', 'Metro 6', 'Metro 7', 'Metro 8', 'Metro 9', 'Metro 10', 'Metro 11', 'Metro 12', 'Metro 13', 'Metro 14', 'Metro 3b', 'Metro 7b', 'Rer A', 'Rer B', 'Rer D', 'Rer E']:
+        for line in ["Metro","RER"]:
+            self.List.addItem(line)
+
+#        for row in already:
+#            self.List.item(row).setSelected ( True)
+
+
+#        find = self.diagList.findItems ( self.Type.text(), QtCore.Qt.MatchContains ) 
+#        if find != []:
+#            self.diagList.setCurrentItem', '(find[0])
+#        else:
+#            self.diagList.addItem(self.Type.text())
+#            self.diagList.setCurrentRow(self.diagList.count() - 1)
+       
+        self.Ok = QPushButton("Ok",self)
+        self.Tout = QPushButton("Tout",self)
+        self.Aucun = QPushButton("Aucun",self)
+        
+        self.Layout.addWidget(self.List,0,0,1,3)
+        self.Layout.addWidget(self.Ok,1,2,1,1)
+        self.Layout.addWidget(self.Aucun,1,1,1,1)
+        self.Layout.addWidget(self.Tout,1,0,1,1)
+
+        self.Ok.clicked.connect(self.close)
+        self.Tout.clicked.connect(self.List.selectAll)
+        self.Aucun.clicked.connect(self.List.clearSelection)
+
+    def closeEvent(self,event):
+        selec = []
+        for it in self.List.selectedItems():
+            selec.append(self.List.row(it))
+        print selec
+        self.emit(SIGNAL("selection(PyQt_PyObject)"),selec)
+#        print 'closing'
+        QDialog.closeEvent (self, event)
