@@ -5,7 +5,7 @@ from PyQt4 import QtCore, QtGui
 import station
 import math
 
-graph = station.graph
+#graph = station.graph
 
 def voisin(S):
     return graph[S].corres
@@ -22,10 +22,10 @@ def Y(S):
 def color(S):
     return graph[S].colorIni.color()
 
-def algo(A,B):
-    C1, T1 = calc(A,B)
+def algo(A,B,G):
+    C1, T1 = calc(A,B,G)
     if T1 - int(T1) == 0:
-        C2, T2 = calc(B,A)
+        C2, T2 = calc(B,A,G)
         if T2 - int(T2) != 0:
             C2 , T2 = [], 1000000000.
     else:
@@ -37,12 +37,13 @@ def algo(A,B):
         C2.reverse()
         return C2, T2
 
-def calc(Deb, Fin):                
+def calc(Deb, Fin,G):                
                 """
                 visit http://en.wikipedia.org/wiki/Dijkstra%27s_algorithm for more information """
 #                print 'Dijkstra : %s --> %s'%(Deb,Fin)
                 reload(station)
                 noeuds = station.station
+                graph = G
                 
                 l__vertexTarget = noeuds[Fin] # get the target
                 if True:
@@ -63,8 +64,8 @@ def calc(Deb, Fin):
                                 # 3. For current node, consider all its unvisited neighbors and calculate their tentative distance.
                                 #print 
 
-                                l__successors = voisin(l__current_vertex)
-                                l__successorsColor = voisinColor(l__current_vertex)
+                                l__successors = graph[l__current_vertex].corres
+                                l__successorsColor = graph[l__current_vertex].corresColor
                                 
                                 
                                 l__old_vertex = noeuds[l__current_vertex][3]
@@ -88,11 +89,11 @@ def calc(Deb, Fin):
                                                 
 
                                                 #if l__successorsColor[l__current_edge] != QtGui.QColor(103,47,143):
-                                                l__newTentativeDistance = int(noeuds[l__current_vertex][0] + math.sqrt( (X(l__current_vertex) - X(l__successor))**2 + (Y(l__current_vertex) - Y(l__successor))**2)) + 60.
+                                                l__newTentativeDistance = int(noeuds[l__current_vertex][0] + math.sqrt( (graph[l__current_vertex].posX - graph[l__successor].posX)**2 + (graph[l__current_vertex].posY - graph[l__successor].posY)**2)) + 60.
                                                 #else:
                                                 #   l__newTentativeDistance = noeuds[l__current_vertex][0] + math.sqrt( (X(l__current_vertex) - X(l__successor))**2 + (Y(l__current_vertex) - Y(l__successor))**2)*.75
                                                 
-                                                if color(l__current_vertex) == station.LigneM and l__old_edge != -1:
+                                                if graph[l__current_vertex].colorIni.color() == station.LigneM and l__old_edge != -1:
                                                         #print 'in the test' , l__successorsColor[l__current_edge], color(l__old_vertex).color()
                                                         if l__old_edge == -2:
                                                         
