@@ -21,9 +21,10 @@ import time
 
 _RAYON = station._RAYON
 _TEMPS_ANIM = 1000
+_FLEUVE = True
 
-graph = station.graph
-
+global graph
+graph = {}
 
   
             
@@ -93,6 +94,7 @@ class Ui_MainWindow(QMainWindow):
     
     def addGPS(self):
         self.scene.addItem(self.gps)
+        self.gps.state = True
         QObject.disconnect(self.gpsButton, SIGNAL("gpsOn"), self.addGPS)
         
     def closeSession(self):
@@ -241,7 +243,25 @@ class Ui_MainWindow(QMainWindow):
                         self.gps.selec()
                         self.gpsCenter()
                     
-                
+    def selecLignes(self):
+#        value, ok = QInputDialog.getItem ( self.view, "Rtap : Lignes", "Selectionnez les lignes que vous voulez afficher.", const QStringList & items, int current = 0, bool editable = true, bool * ok = 0, Qt::WindowFlags flags = 0 )
+        graph.clear()
+        fullList = station.Metro + station.Rer
+        liste = []
+#        for line in self.Lignes[1:]:
+#            liste.append(fullList.index(line))
+        diag = classes.diagLigne(liste,self.view)
+        QObject.connect(diag,SIGNAL("selection(PyQt_PyObject)"),self.selecLignesProcess)
+        diag.show()
+        
+    def selecLignesProcess(self,liste):
+        reload(station)
+        self.Lignes = [station.GPS]
+        fullList = station.Metro,station.Rer
+        for it in liste:
+            self.Lignes += fullList[it]
+        self.buildGraph()
+        self.drawGraph()
 
     def setSelec(self,Name):
         
@@ -375,15 +395,15 @@ class Ui_MainWindow(QMainWindow):
         if self.Selec[0] == 'GPS':
             proche = self.gpsSearch(self.gps.pos())
             graph['GPS'].addCorres(str(proche))
-            self.Chemin , tps = dijkstra.algo(str(proche),self.Selec[1])
+            self.Chemin , tps = dijkstra.algo(str(proche),self.Selec[1],graph)
             self.Chemin = ['GPS'] + self.Chemin
         elif  self.Selec[1] == 'GPS':
             proche = self.gpsSearch(self.gps.pos())
-            self.Chemin ,tps = dijkstra.algo(self.Selec[0],str(proche)) 
+            self.Chemin ,tps = dijkstra.algo(self.Selec[0],str(proche),graph) 
             self.Chemin += ["GPS"]
             graph[str(proche)].addCorres("GPS")
         else:
-            self.Chemin, tps = dijkstra.algo(self.Selec[0],self.Selec[1])
+            self.Chemin, tps = dijkstra.algo(self.Selec[0],self.Selec[1],graph)
 
 #        print 'tps de calcul', time.time() - t0
 
@@ -477,29 +497,60 @@ class Ui_MainWindow(QMainWindow):
             self.panAction.move(app.desktop().screenGeometry().width()-100,self.panAction.y())
             self.panAction.animMargin.start()
 
+    def buildGraph(self):
+        toFix = []
+        graph.clear()
+        for ligne in self.Lignes:
+            for stop in ligne:
+                if stop in graph:
+                    for dest in ligne[stop].corres:
+                        graph[stop].addCorres(dest,ligne[stop].color.color())
+                else:
+                    graph[stop] = ligne[stop]
 
         
-    def setupUi(self, App):
-        self.setWindowTitle("Rtap")
-        self.resize(800,480)
-        global app
-        app = App
+    def drawGraph(self):
+        for item in self.scene.items():
+            self.scene.removeItem(item)
+        if _FLEUVE:
+            self.drawFleuve()
+        #Segment entre stations
+        for dep in graph:
+            k = 0
+            while k < len(graph[dep].corres):
+                dest = graph[dep].corres[k]
+                try:
+                    self.scene.addLine ( 
+                        graph[dep].posX + _RAYON/2, 
+                        graph[dep].posY + _RAYON/2, 
+                        graph[dest].posX + _RAYON/2, 
+                        graph[dest].posY + _RAYON/2, 
+                        QPen(graph[dep].corresColor[k], _RAYON/4)
+                        )        
+                except KeyError:
+                    graph[dep].removeCorres(dest)
+                    print dep, graph[dep].corres
 
-        self.centralWidget = QWidget(self)
-        self.Selec = ('','')
-        self.CheminItem = []
-        self.Chemin = []
+                try:
+                    if graph[dep].corresColor[k] == graph[dep].corresColor[k+1] and graph[dep].corresColor[k] != station.LigneM:
+                        k += 2
+                    else:
+                        k += 1
+                except IndexError:
+                    k += 1
 
-        menubar = QMenuBar(self)
-        self.setMenuBar(menubar)
-        
-        menuChercher = QAction("Recherche",self)
-        menubar.addAction(menuChercher)
-        QObject.connect(menuChercher, SIGNAL("triggered()"), self.search)
-        
-        self.scene = classes.Carte(self)
-        self.scene.setSceneRect(-815.90800894434585, -2585.2493331816809, 5397.5130039461728, 3900.3854289115216)
-        
+        #Stations
+        for value in graph:
+            try:
+                if graph[value].name[-1] != "]" and graph[value].name != 'GPS':
+                    self.scene.addItem(graph[value])
+            except IndexError:
+                self.scene.addItem(graph[value])
+        #Gps
+        if self.gps.state:
+            self.scene.addItem(self.gps)
+                
+    def drawFleuve(self):
         #Fleuve
         fleuve = QPainterPath()
         fleuve.moveTo(station.SeineX[0], station.SeineY[0])
@@ -531,39 +582,50 @@ class Ui_MainWindow(QMainWindow):
             k += 1
            
         self.scene.addPath(fleuve, QPen( QColor(165,191,221), _RAYON*.8))
+
+    
+    def setupUi(self, App):
+        self.setWindowTitle("Rtap")
+        self.resize(800,480)
+        global app
+        app = App
+
+        self.centralWidget = QWidget(self)
+        self.Selec = ('','')
+        self.CheminItem = []
+        self.Chemin = []
+        self.Lignes = [station.GPS] + station.Metro + station.Rer
+
+
+        menubar = QMenuBar(self)
+        self.setMenuBar(menubar)
         
-        #Segment entre stations
-        for dep in graph:
-            k = 0
-            while k < len(graph[dep].corres):
-                dest = graph[dep].corres[k]
-                
-                self.scene.addLine ( 
-                    graph[dep].posX + _RAYON/2, 
-                    graph[dep].posY + _RAYON/2, 
-                    graph[dest].posX + _RAYON/2, 
-                    graph[dest].posY + _RAYON/2, 
-                    QPen(graph[dep].corresColor[k], _RAYON/4)
-                    )        
+        menuChercher = QAction("Recherche",self)
+        menubar.addAction(menuChercher)
+        QObject.connect(menuChercher, SIGNAL("triggered()"), self.search)
 
-                try:
-                    if graph[dep].corresColor[k] == graph[dep].corresColor[k+1] and graph[dep].corresColor[k] != station.LigneM:
-                        k += 2
-                    else:
-                        k += 1
-                except IndexError:
-                    k += 1
+        menuLignes = QAction("Lignes",self)
+        menubar.addAction(menuLignes)
+        QObject.connect(menuLignes, SIGNAL("triggered()"), self.selecLignes)
 
-        #Stations
-        for value in graph:
-            if graph[value].name[-1] != "]" and graph[value].name != 'GPS':
-                self.scene.addItem(graph[value])
 
 
+########## GPS
+
+#        self.gps = graph["GPS"]
+        self.gps = classes.Gps()
+
+########## Scene
+        
+        self.scene = classes.Carte(self)
+#        self.scene.setSceneRect(-815.90800894434585, -2585.2493331816809, 5397.5130039461728, 3900.3854289115216)
+        
+        self.buildGraph()
+        self.drawGraph()
+
         QObject.connect(self.scene, SIGNAL("dblclicked(QPointF)"), self.rectSelec)
-
-
         self.scene.setBackgroundBrush(self.palette().shadow().color())
+########## View
         self.view = classes.Fond(self.scene)
         self.view.setDragMode(1)
         self.view.setVerticalScrollBarPolicy ( Qt.ScrollBarAlwaysOff )
@@ -572,6 +634,8 @@ class Ui_MainWindow(QMainWindow):
         self.rectCalc = QGraphicsRectItem (self.view.sceneRect())
         self.rectCalc.setBrush(QBrush(QColor(0,0,0,153)))
 
+########## Panneaux
+
         self.panDepart = classes.PanStation(self.view)
         self.panDepart.setGeometry(900,0,250,180)
         QObject.connect(self.panDepart, SIGNAL("released(QString)"), self.deselec)
@@ -589,8 +653,8 @@ class Ui_MainWindow(QMainWindow):
         QObject.connect(self.panAction, SIGNAL("play"), self.play)
         self.panAction.show()
         self.panAction.animMargin.start()
-
-########## GPS
+        
+########## GPS Button
 
         self.gpsButton = classes.GpsButton(self.view)
         QObject.connect(self.gpsButton, SIGNAL("gpsOn"), self.m_session.open)
@@ -600,9 +664,6 @@ class Ui_MainWindow(QMainWindow):
         self.gpsButton.setGeometry(16,app.desktop().screenGeometry().height()-80-56,80,80)
         self.gpsButton.show()
 
-#        self.gps = graph["GPS"]
-        self.gps = classes.Gps()
-
 #########
 
         if app.desktop().screenGeometry().width() < app.desktop().screenGeometry().height():
